# Notes on extractors
These are very basic extractors that allow to test the functionality and ensure that are there are a minimum number of
very well established package requirements. Typical extractors have more complicated requirements.

Additionally, scientists should adopt, change the extractors to their liking: hence these act as starting position.